@@ -6,6 +6,7 @@ use Path::Class;
 use Scalar::Util qw(weaken);
 
 use Module::Setup::Flavor;
+use Module::Setup::Path::Dir;
 
 sub new {
     my($class, %args) = @_;
@@ -23,23 +24,25 @@ sub add_trigger {
 }
 
 sub append_template_file {
-    my($self, $context, $template_vars, $module_attribute) = @_;
-    my $caller = caller;
-
+    my($self, $context, $caller) = @_;
+    $caller = caller unless $caller;
     my @template = Module::Setup::Flavor::loader($caller);
 
     for my $tmpl (@template) {
-        next unless exists $tmpl->{file};
-        my $dist_path = Path::Class::File->new(@{ $module_attribute->{dist_path} }, $tmpl->{file});
-
+        if (exists $tmpl->{dir}) {
+            Module::Setup::Path::Dir->new($context->distribute->dist_path, split('/', $tmpl->{dir}))->mkpath;
+            next;
+        } elsif (!exists $tmpl->{file}) {
+            next;
+        }
         my $options = {
-            dist_path => $dist_path,
+            dist_path => $context->distribute->dist_path->file(split('/', $tmpl->{file})),
             template  => $tmpl->{template},
-            vars      => $template_vars,
+            vars      => $context->distribute->template_vars,
             content   => undef,
         };
         $options->{chmod} = $tmpl->{chmod} if $tmpl->{chmod};
-        $context->write_template($options);
+        $context->distribute->write_template($context, $options);
     }
 }
 
@@ -65,7 +68,7 @@ module attribute setup L<Module::Setup::Plugin::VC::SVN>
 
 template parameters setup
 
-=head2 append_template_file $template_vars, $module_attribute
+=head2 append_template_file
 
 add module template file for new module L<Module::Setup::Plugin::VC::Git>
 
@@ -73,27 +76,25 @@ add module template file for new module L<Module::Setup::Plugin::VC::Git>
 
 for template process L<Module::Setup::Plugin::Template>
 
-=head2 check_skeleton_directory $attributes
+=head2 replace_distribute_path $options
+
+for distribute path rewrite phase
+
+=head2 check_skeleton_directory
 
   for test L<Module::Setup::Plugin::Test::Makefile>
 
-  $attributes = +{
-      module_attribute => +{ module_attribute },
-      template_vars    => +{ template_vars },
-      instal_files     => +[ install_files ],
-  };
-
-=head2 after_create_skeleton $attributes
+=head2 after_create_skeleton
 
 after create_skeleton
 
-=head2 finalize_create_skeleton $attributes
+=head2 finalize_create_skeleton
 
 last trigger of run method
 
 =head1 Plugin Example
 
-~/.module-setup/flavor/myflavor/plugins/plugin.pl
+~/.module-setup/flavor/myflavor/plugins/plugin.pm
   package MyFlavor::Plugin;
   use strict;
   use warnings;
